biotraj
=======

Loading and saving raw data in trajectory formats.

This package is small excerpt from https://github.com/mdtraj/mdtraj containing only the
functionality to read and write trajectory files.
It is not intended to be used as a separate package, but is a dependency for
https://github.com/biotite-dev/biotite.
It is not integrated into the Biotite package directly due to an incompatible license.

Currently supported formats:

- *XTC*
- *TRR*
- *NetCDF*
- *DCD*
